pub struct Token {
pub kind: TokenKind,
pub span: Span,
}Expand description
A lexed token: its kind plus the source span it was read from.
Fields
kind: TokenKindWhat kind of token this is (and any literal payload).
span: SpanThe byte range in the source the token was read from.